@@ -19,13 +19,15 @@ import re
 from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
+from google.api_core.client_options import ClientOptions  # type: ignore
 from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+OptionalRetry = Union[retries.Retry, object]
+
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.translate_v3beta1.services.translation_service import pagers
@@ -167,16 +169,16 @@ class TranslationServiceAsyncClient:
 
     async def translate_text(
         self,
-        request: translation_service.TranslateTextRequest = None,
+        request: Union[translation_service.TranslateTextRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.TranslateTextResponse:
         r"""Translates input text and returns translated text.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.TranslateTextRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.TranslateTextRequest, dict]):
                 The request object. The request message for synchronous
                 translation.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -214,19 +216,19 @@ class TranslationServiceAsyncClient:
 
     async def detect_language(
         self,
-        request: translation_service.DetectLanguageRequest = None,
+        request: Union[translation_service.DetectLanguageRequest, dict] = None,
         *,
         parent: str = None,
         model: str = None,
         mime_type: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.DetectLanguageResponse:
         r"""Detects the language of text within a request.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.DetectLanguageRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.DetectLanguageRequest, dict]):
                 The request object. The request message for language
                 detection.
             parent (:class:`str`):
@@ -327,12 +329,12 @@ class TranslationServiceAsyncClient:
 
     async def get_supported_languages(
         self,
-        request: translation_service.GetSupportedLanguagesRequest = None,
+        request: Union[translation_service.GetSupportedLanguagesRequest, dict] = None,
         *,
         parent: str = None,
         display_language_code: str = None,
         model: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.SupportedLanguages:
@@ -340,7 +342,7 @@ class TranslationServiceAsyncClient:
         translation.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.GetSupportedLanguagesRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.GetSupportedLanguagesRequest, dict]):
                 The request object. The request message for discovering
                 supported languages.
             parent (:class:`str`):
@@ -456,16 +458,16 @@ class TranslationServiceAsyncClient:
 
     async def translate_document(
         self,
-        request: translation_service.TranslateDocumentRequest = None,
+        request: Union[translation_service.TranslateDocumentRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.TranslateDocumentResponse:
         r"""Translates documents in synchronous mode.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.TranslateDocumentRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.TranslateDocumentRequest, dict]):
                 The request object. A document translation request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -504,9 +506,9 @@ class TranslationServiceAsyncClient:
 
     async def batch_translate_text(
         self,
-        request: translation_service.BatchTranslateTextRequest = None,
+        request: Union[translation_service.BatchTranslateTextRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -521,7 +523,7 @@ class TranslationServiceAsyncClient:
         of the call.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.BatchTranslateTextRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.BatchTranslateTextRequest, dict]):
                 The request object. The batch translation request.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
@@ -572,9 +574,14 @@ class TranslationServiceAsyncClient:
 
     async def batch_translate_document(
         self,
-        request: translation_service.BatchTranslateDocumentRequest = None,
+        request: Union[translation_service.BatchTranslateDocumentRequest, dict] = None,
         *,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        parent: str = None,
+        source_language_code: str = None,
+        target_language_codes: Sequence[str] = None,
+        input_configs: Sequence[translation_service.BatchDocumentInputConfig] = None,
+        output_config: translation_service.BatchDocumentOutputConfig = None,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -589,8 +596,65 @@ class TranslationServiceAsyncClient:
         the call.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.BatchTranslateDocumentRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.BatchTranslateDocumentRequest, dict]):
                 The request object. The BatchTranslateDocument request.
+            parent (:class:`str`):
+                Required. Location to make a regional call.
+
+                Format:
+                ``projects/{project-number-or-id}/locations/{location-id}``.
+
+                The ``global`` location is not supported for batch
+                translation.
+
+                Only AutoML Translation models or glossaries within the
+                same region (have the same location-id) can be used,
+                otherwise an INVALID_ARGUMENT (400) error is returned.
+
+                This corresponds to the ``parent`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            source_language_code (:class:`str`):
+                Required. The BCP-47 language code of
+                the input document if known, for
+                example, "en-US" or "sr-Latn". Supported
+                language codes are listed in Language
+                Support
+                (https://cloud.google.com/translate/docs/languages).
+
+                This corresponds to the ``source_language_code`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            target_language_codes (:class:`Sequence[str]`):
+                Required. The BCP-47 language code to
+                use for translation of the input
+                document. Specify up to 10 language
+                codes here.
+
+                This corresponds to the ``target_language_codes`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            input_configs (:class:`Sequence[google.cloud.translate_v3beta1.types.BatchDocumentInputConfig]`):
+                Required. Input configurations.
+                The total number of files matched should
+                be <= 100. The total content size to
+                translate should be <= 100M Unicode
+                codepoints. The files must use UTF-8
+                encoding.
+
+                This corresponds to the ``input_configs`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
+            output_config (:class:`google.cloud.translate_v3beta1.types.BatchDocumentOutputConfig`):
+                Required. Output configuration.
+                If 2 input configs match to the same
+                file (that is, same input path), we
+                don't generate output for duplicate
+                inputs.
+
+                This corresponds to the ``output_config`` field
+                on the ``request`` instance; if ``request`` is provided, this
+                should not be set.
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -608,8 +672,38 @@ class TranslationServiceAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
+        # Sanity check: If we got a request object, we should *not* have
+        # gotten any keyword arguments that map to the request.
+        has_flattened_params = any(
+            [
+                parent,
+                source_language_code,
+                target_language_codes,
+                input_configs,
+                output_config,
+            ]
+        )
+        if request is not None and has_flattened_params:
+            raise ValueError(
+                "If the `request` argument is set, then none of "
+                "the individual field arguments should be set."
+            )
+
         request = translation_service.BatchTranslateDocumentRequest(request)
 
+        # If we have keyword arguments corresponding to fields on the
+        # request, apply these.
+        if parent is not None:
+            request.parent = parent
+        if source_language_code is not None:
+            request.source_language_code = source_language_code
+        if output_config is not None:
+            request.output_config = output_config
+        if target_language_codes:
+            request.target_language_codes.extend(target_language_codes)
+        if input_configs:
+            request.input_configs.extend(input_configs)
+
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
         rpc = gapic_v1.method_async.wrap_method(
@@ -640,11 +734,11 @@ class TranslationServiceAsyncClient:
 
     async def create_glossary(
         self,
-        request: translation_service.CreateGlossaryRequest = None,
+        request: Union[translation_service.CreateGlossaryRequest, dict] = None,
         *,
         parent: str = None,
         glossary: translation_service.Glossary = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -652,7 +746,7 @@ class TranslationServiceAsyncClient:
         Returns NOT_FOUND, if the project doesn't exist.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.CreateGlossaryRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.CreateGlossaryRequest, dict]):
                 The request object. Request message for CreateGlossary.
             parent (:class:`str`):
                 Required. The project name.
@@ -728,11 +822,11 @@ class TranslationServiceAsyncClient:
 
     async def list_glossaries(
         self,
-        request: translation_service.ListGlossariesRequest = None,
+        request: Union[translation_service.ListGlossariesRequest, dict] = None,
         *,
         parent: str = None,
         filter: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListGlossariesAsyncPager:
@@ -740,7 +834,7 @@ class TranslationServiceAsyncClient:
         doesn't exist.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.ListGlossariesRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.ListGlossariesRequest, dict]):
                 The request object. Request message for ListGlossaries.
             parent (:class:`str`):
                 Required. The name of the project
@@ -855,10 +949,10 @@ class TranslationServiceAsyncClient:
 
     async def get_glossary(
         self,
-        request: translation_service.GetGlossaryRequest = None,
+        request: Union[translation_service.GetGlossaryRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> translation_service.Glossary:
@@ -866,7 +960,7 @@ class TranslationServiceAsyncClient:
         exist.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.GetGlossaryRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.GetGlossaryRequest, dict]):
                 The request object. Request message for GetGlossary.
             name (:class:`str`):
                 Required. The name of the glossary to
@@ -936,10 +1030,10 @@ class TranslationServiceAsyncClient:
 
     async def delete_glossary(
         self,
-        request: translation_service.DeleteGlossaryRequest = None,
+        request: Union[translation_service.DeleteGlossaryRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> operation_async.AsyncOperation:
@@ -948,7 +1042,7 @@ class TranslationServiceAsyncClient:
         doesn't exist.
 
         Args:
-            request (:class:`google.cloud.translate_v3beta1.types.DeleteGlossaryRequest`):
+            request (Union[google.cloud.translate_v3beta1.types.DeleteGlossaryRequest, dict]):
                 The request object. Request message for DeleteGlossary.
             name (:class:`str`):
                 Required. The name of the glossary to
