@@ -230,6 +230,8 @@ class Translation(proto.Message):
 class DetectLanguageRequest(proto.Message):
     r"""The request message for language detection.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         parent (str):
             Required. Project or location to make a call. Must refer to
@@ -258,6 +260,8 @@ class DetectLanguageRequest(proto.Message):
             If not specified, the default model is used.
         content (str):
             The content of the input stored as a string.
+
+            This field is a member of `oneof`_ ``source``.
         mime_type (str):
             Optional. The format of the source text, for
             example, "text/html", "text/plain". If left
@@ -417,6 +421,8 @@ class GcsSource(proto.Message):
 class InputConfig(proto.Message):
     r"""Input configuration for BatchTranslateText request.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         mime_type (str):
             Optional. Can be "text/plain" or "text/html". For ``.tsv``,
@@ -443,6 +449,8 @@ class InputConfig(proto.Message):
 
             The other supported file extensions are ``.txt`` or
             ``.html``, which is treated as a single large chunk of text.
+
+            This field is a member of `oneof`_ ``source``.
     """
 
     mime_type = proto.Field(proto.STRING, number=1,)
@@ -468,6 +476,8 @@ class GcsDestination(proto.Message):
 class OutputConfig(proto.Message):
     r"""Output configuration for BatchTranslateText request.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.translate_v3beta1.types.GcsDestination):
             Google Cloud Storage destination for output content. For
@@ -546,6 +556,7 @@ class OutputConfig(proto.Message):
             glossary_error_file will be generated that contains error
             details. glossary_error_file has format of
             gs://translation_test/a_b_c\_'trg'_glossary_errors.[extension]
+            This field is a member of `oneof`_ ``destination``.
     """
 
     gcs_destination = proto.Field(
@@ -556,13 +567,23 @@ class OutputConfig(proto.Message):
 class DocumentInputConfig(proto.Message):
     r"""A document translation request input config.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         content (bytes):
             Document's content represented as a stream of
             bytes.
+
+            This field is a member of `oneof`_ ``source``.
         gcs_source (google.cloud.translate_v3beta1.types.GcsSource):
             Google Cloud Storage location. This must be a single file.
             For example: gs://example_bucket/example_file.pdf
+            This field is a member of `oneof`_ ``source``.
         mime_type (str):
             Specifies the input document's mime_type.
 
@@ -587,6 +608,8 @@ class DocumentInputConfig(proto.Message):
 class DocumentOutputConfig(proto.Message):
     r"""A document translation request output config.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.translate_v3beta1.types.GcsDestination):
             Optional. Google Cloud Storage destination for the
@@ -638,6 +661,8 @@ class DocumentOutputConfig(proto.Message):
             Callers should expect no partial outputs. If there is any
             error during document translation, no output will be stored
             in the Cloud Storage bucket.
+
+            This field is a member of `oneof`_ ``destination``.
         mime_type (str):
             Optional. Specifies the translated document's mime_type. If
             not specified, the translated file's mime type will be the
@@ -958,6 +983,8 @@ class BatchTranslateResponse(proto.Message):
 class GlossaryInputConfig(proto.Message):
     r"""Input configuration for glossaries.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_source (google.cloud.translate_v3beta1.types.GcsSource):
             Required. Google Cloud Storage location of glossary data.
@@ -985,6 +1012,8 @@ class GlossaryInputConfig(proto.Message):
                defined for Google Translation Toolkit and documented in
                `Use a
                glossary <https://support.google.com/translatortoolkit/answer/6306379?hl=en>`__.
+
+            This field is a member of `oneof`_ ``source``.
     """
 
     gcs_source = proto.Field(
@@ -995,6 +1024,13 @@ class GlossaryInputConfig(proto.Message):
 class Glossary(proto.Message):
     r"""Represents a glossary built from user provided data.
 
+    This message has `oneof`_ fields (mutually exclusive fields).
+    For each oneof, at most one member field can be set at the same time.
+    Setting any member of the oneof automatically clears all other
+    members.
+
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         name (str):
             Required. The resource name of the glossary. Glossary names
@@ -1002,8 +1038,12 @@ class Glossary(proto.Message):
             ``projects/{project-number-or-id}/locations/{location-id}/glossaries/{glossary-id}``.
         language_pair (google.cloud.translate_v3beta1.types.Glossary.LanguageCodePair):
             Used with unidirectional glossaries.
+
+            This field is a member of `oneof`_ ``languages``.
         language_codes_set (google.cloud.translate_v3beta1.types.Glossary.LanguageCodesSet):
             Used with equivalent term set glossaries.
+
+            This field is a member of `oneof`_ ``languages``.
         input_config (google.cloud.translate_v3beta1.types.GlossaryInputConfig):
             Required. Provides examples to build the
             glossary from. Total glossary must not exceed
@@ -1347,6 +1387,8 @@ class BatchTranslateDocumentRequest(proto.Message):
 class BatchDocumentInputConfig(proto.Message):
     r"""Input configuration for BatchTranslateDocument request.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_source (google.cloud.translate_v3beta1.types.GcsSource):
             Google Cloud Storage location for the source input. This can
@@ -1369,6 +1411,8 @@ class BatchDocumentInputConfig(proto.Message):
             ``.xlsx`` is 100MB. The max file size to support for
             ``.pdf`` is 1GB and the max page limit is 1000 pages. The
             max file size to support for all input documents is 1GB.
+
+            This field is a member of `oneof`_ ``source``.
     """
 
     gcs_source = proto.Field(
@@ -1379,6 +1423,8 @@ class BatchDocumentInputConfig(proto.Message):
 class BatchDocumentOutputConfig(proto.Message):
     r"""Output configuration for BatchTranslateDocument request.
 
+    .. _oneof: https://proto-plus-python.readthedocs.io/en/stable/fields.html#oneofs-mutually-exclusive-fields
+
     Attributes:
         gcs_destination (google.cloud.translate_v3beta1.types.GcsDestination):
             Google Cloud Storage destination for output content. For
@@ -1433,6 +1479,8 @@ class BatchDocumentOutputConfig(proto.Message):
             ``glossary_error_output``:
             gs://translation_test/a_b_c*\ [trg]_glossary_translation.txt
             The error output is a txt file containing error details.
+
+            This field is a member of `oneof`_ ``destination``.
     """
 
     gcs_destination = proto.Field(
